#!~/usr/anaconda2/bin/python
# ######################################### #
# Time-stamp: <2018-10-02 12:56:42 dkunkel> #
# ######################################### #
'''
USING python 2.7.14 |Anaconda custom (64-bit)| (default, Oct 16 2017, 17:29:19)

DESCRIPTION:
Read FLEXPART output of simulations for tracing
plumes from a source point.


USAGE OF THE SCRIPT:
python plot_tracer_plumes.py AIRMASS_PERIOD 

AIRMASS_PERIOD can be period1, period2, period3
=> merged and averaged daily FLEXPART runs using nco tools.

'''
# ######################################### # 
# LOAD MODULES
# ######################################### # runs with:
import numpy as np                          # Version: 1.8.2
import matplotlib.pyplot as plt             # Version: 1.4.2
from matplotlib import cm                   # Version: 1.4.2
import matplotlib.colors as mcolors         # Version: 1.4.2
from mpl_toolkits.basemap import Basemap    # Version: 1.0.7
import netCDF4 as nc4
import sys, os, fnmatch, re                 # Version:
# ######################################### #

# External input:
if len(sys.argv) == 2:
    itime = str(sys.argv[1]) # period[1,2,3]
else:
    exit(" input error ")
# ######################################
#
# INPUT PATHS:
#
# ######################################
# base path to data
path0="/ipa/utls/dkunkel/exchange/2018_heiko/"
# ######################################
# path to data of specific airmass period
path1=path0+"airmass_"+str(itime)+"/"
# filename of flexpart output file (mean of merged)
fname="mean_grid_time_mean_"+str(itime)+".nc"
# full path to flexpart output file
pfile=path1+fname
# 
print '*** file: '+pfile
# ######################################
# outpath where to put the pdf/png
opath="../plots/"
# check if data paths exist
xtest=os.path.exists(opath)
if xtest == False:
    os.mkdir(opath)
# ######################################
# general marker of the campaign
marker="acloud_ny17_v3"
# ######################################
# tracer name
var="spec001_mr"
# #
# suffix for plots
suffix = 'eps'
# #
# logical whether to plot trajectories (True) or not (False)
ltra=False
# ######################################### #
# END DEFINITION PART 
# ######################################### #

# ######################################### #
#### ROUTINES FOR GETTING DATA:
#
def get_tra_dates(path):
    # input:
    # path to folder with airmass data (period[1,2,3])
    # search for trajectoris_*.txt files in a directory
    alltrafiles=fnmatch.filter(os.listdir(path),'trajectories_*.txt')
    # initialize an empty list for the dates
    dates=[]
    for traf in alltrafiles:
        # find index of '_' to get the date in the trajectories file
        ind1=traf.find('_')
        
        dates.append(traf[ind1+1:ind1+9])
    print dates.sort()
    if len(dates) > 0:
        return dates
    else:
        print " no trajectory dates found, please check path: "
        print " "+path
        print " abort"
        exit()        
#
def read_trajectories(ptra):
    # read trajectories file from flexpart
    # input : path to tra file
    # output: data in tra file
    # open file
    # read general header
    with open(ptra,'r') as ft:
    # read first line (general info about sim start and flexpart version)
        line1=ft.readline()
    # skip second line (parameter: method, lsubgrid, lconvection)
        line2=ft.readline()
    # third line gives the number of release points
    # == number of center of mass trajectories
        line3=ft.readline()
    #
    ntra = int(line3)
    #
    # now read start info of release points == start of center of mass trajs
    with open(ptra, 'r') as ft:
        relinfo = []
        relname = []
        tradata = []
        for i in xrange(0,3):
            ft.next()
        ii = 0
        for i in xrange(0,2*ntra):
            help1=ft.next()
            if i%2:
                relname.append(help1)
                ii=ii+1
            else:
                relinfo.append([x for x in help1.split()])
        for line in ft:
            tradata.append(line)
            
    # tradata: only number of release point, time, lon, lat, alt
    tracenter = np.zeros((5, len(tradata)))
    for i in xrange(0,len(tradata)):
        tracenter[:,i] = tradata[i].split()[0:5]
    
    return [relname,relinfo, tracenter]
# some helper for the trajectories
def tra_colors(per):
    if per == 'period1':
        tcol='blue'
    elif per == 'period2':
        tcol = 'red'
    elif per == 'period3':
        tcol = 'green'
    return tcol
def tra_colors_range(per):
    # if per == 'period1':
    #     tcol=cm.Blues
    # elif per == 'period2':
    #     tcol =cm.Reds
    # elif per == 'period3':
    #     tcol =cm.Greens
    # latest version, 2018/03/23
    tcol=cm.Blues_r
    return tcol

# ######################################
#### ROUTINES FOR GETTING DATA from the nc files

def get_var4(pfile1,var):
    ff = nc4.Dataset(pfile1,'r')
    myvar=ff.variables[var]
    return myvar

def get_dims(pfile1):
    ff = nc4.Dataset(pfile1,'r')
    alldim=ff.dimensions
    return alldim

# ######################################
# main program with the plotting 
# ######################################
def main():
    ### MAIN:
    # get dimension as a dictionary
    dims = get_dims(pfile)
    # get length of dimensions
    nlen=len(dims['longitude'])
    nlat=len(dims['latitude'])
    nlev=len(dims['height'])
    nspec=len(dims['numspec'])
    npoint=len(dims['pointspec'])
    nage=len(dims['nageclass'])

    # get grid info 
    # latitude
    lat= get_var4(pfile,"latitude")
    # longitue
    lon= get_var4(pfile,"longitude")
    # level
    lev= get_var4(pfile,"height")
    # release heights
    # bottom
    relbot=get_var4(pfile,"RELZZ1")
    nrelbot=len(relbot)
    # top
    reltop=get_var4(pfile,"RELZZ2")
    nreltop=len(reltop)
    assert nreltop == nrelbot

    relstart=get_var4(pfile,"RELSTART")
    relend  =get_var4(pfile,"RELEND")

    # get full tracer with
    # dimensions: [nageclass, pointspec, height, latitude, longitude] 
    trac = get_var4(pfile,var)
    # reduce to 3d variable [time, height, latitude, longitude]
    ptrac = trac[0,0,:,:,:]
    # current altitude levels for this simulation:
    # height = 200, 500, 1000, 2500, 5000, 15000
    #
    # plot 500 m and full column
    ptrac_plot1 = np.sum(ptrac[0:2,:,:],axis=0) # lowest levels 
    ptrac_plot2 = np.sum(ptrac, axis=0)         # full column
    # -> both arrays are 2d means
    '''
    EXAMPLE to obtain data for specific alitutde ranges
    ---
    If you want to plot the level up to a specific altitude, e.g., 200m 
    you have to sum up the lowest levels
    ! --------------------------
    level of alitudes in the netcdf files (upper borders):
    height = 50, 100, 200, 500, 1000, 2000, 4000, 6000, 8000, 10000 ;
    ! --------------------------
    --> so for 0-200 m you need the first 3 levels:
    ! --------------------------
    phelp = trac[:,0:3,:,:]
    ptracl= np.sum(phelp,axis=1)
    ! --------------------------
    then ptracl holds the data for 0-200 m
    '''
    del trac, ptrac
    #print ptrac.shape
    if ltra:
        tra_dates = get_tra_dates(path1)
        # get trajectory informations
        nt=0
        for tra_dat in tra_dates:
            trafile=path1+'trajectories_'+tra_dat+'.txt'
            tra_data = read_trajectories(trafile)
            centertra=tra_data[2]
            # GET CENTER OF MASS TRAJECTORY
            # get lon / lat of center tra
            clon = []
            clat = []
            calt = []
            tralen=len(centertra[0,:])
            if tralen > 44:
                tralen = 44
            elif tralen < 44:
                print " *** center of mass trajectory too short "
            alldates=len(tra_dates)
            # initialize the large list which should contain all the stuff
            if nt == 0:
                alllon = np.zeros((alldates,tralen))
                alllat = np.zeros((alldates,tralen))
                allalt = np.zeros((alldates,tralen))


            for i in xrange(0, len(centertra[0,:])):
                if int(centertra[0,i]) == 1 and centertra[1,i] < 9.e5:

                    clon.append(float(centertra[2,i]))
                    clat.append(float(centertra[3,i]))
                    calt.append(float(centertra[4,i]))

            #print len(clon), len(clat), len(calt)
            alllon[nt,:] = clon[:tralen]
            alllat[nt,:] = clat[:tralen]
            allalt[nt,:] = calt[:tralen]
            nt += 1
        print alllon.shape, alllat.shape, allalt.shape
    
    # START THE PLOT ROUTINE FOR EACH RELEASE POINT:
    for jd in xrange(0,npoint):
 
        ######################################### #
        ######################################### #
        # plot data
        # ######################################### #
        
        
        # ######################################### #
        # ######################################### #
        # initialize the plot
        # set up a 2x2 plot matrix
        # so each of the release altitudes gets one panel
        #
        #   title
        #  --------------
        # |  full column |
        # |______________|
        # |  500 m       |
        # |______________|
        #  color bar           
        #
        for jn in xrange(0,2):
            fig, ax = plt.subplots(nrows=1, ncols=1, figsize=(5.5,5.5))
            # set the grid
            lons, lats = np.meshgrid(lon,lat)
            # # set the colorlevels
            levels=([0.01,0.02,0.05,0.1,0.2,0.5,1.0,2.0,5.0,10.,20.])
            # set the colormap --> yellow orange red
            cols=cm.YlOrRd
            ### adjust colors
            norm = mcolors.BoundaryNorm(levels,ncolors=cols.N, clip=False)
            ### set the variable and the title of each panel:

            if jn==0:
                pp = ptrac_plot2
                ii=0
                stitle="Total column (0-15 km)"
                if ltra:
                    outfile=opath+marker+"_plume_"+var+"_"+str(itime)+"_backward_wt_full_column."+suffix
                else:
                    outfile=opath+marker+"_plume_"+var+"_"+str(itime)+"_backward_full_column."+suffix
            elif jn==1:
                pp = ptrac_plot1
                ii=1
                stitle="0-500 m"
                if ltra:
                    outfile=opath+marker+"_plume_"+var+"_"+str(itime)+"_backward_wt_lowest_500m."+suffix
                else:
                    outfile=opath+marker+"_plume_"+var+"_"+str(itime)+"_backward_lowest_500m."+suffix

                
            # setup polar stereo plot
            m = Basemap(projection='npstere',
                        resolution='c',boundinglat=50.,lon_0=10.)
            # add coastlines 
            m.drawcoastlines()
            # add latitudes
            parallels = np.arange(0.,80,10.)
            m.drawparallels(parallels,labels=[0,0,0,0],fontsize=12)
            # add longitudes
            meridians = np.arange(0.,360.,30.)
            m.drawmeridians(meridians,labels=[0,0,0,0],fontsize=12)
            # set the boarders
            x, y = m(lons, lats)               
            # set the title (no title wanted)
            #ax[ii].set_title(stitle, fontsize=14)
            # add the date (no date wanted) 
            #if jn==0:
            #    # add the date to the figure
            #    ax[ii].text(0.20, 2.5, itime, color="black", \
            #                bbox=dict(facecolor='white', \
            #                          pad=2, edgecolor='white'),  fontsize=16)
            #
            # do the contour filled plot
            cs0 = ax.contourf(x,y,pp[:,:], levels=levels,\
                                  cmap=cols,extend="max",norm=norm)
            # white color below last levels contour
            cs0.cmap.set_under('w')
            # include trajectories if desired, set ltra=True
            if ltra:
                # add the center of mass trajectories
                # get the color for the trajectories
                tracol=tra_colors_range(str(itime))
                # normalize the color range to given number
                cNorm  = mcolors.Normalize(vmin=0, vmax=len(tra_dates))
                # do some magic
                scalarMap = cm.ScalarMappable(norm=cNorm, cmap=tracol)
                
                if jn==0 or jn==1: # only in the total column plot
                    for nt in xrange(0,alllon.shape[0]):
                        print " *** "+str(tra_dates[nt]).split('_')[0]
                        xc,yc = m(alllon[nt,:],alllat[nt,:])
                        colorVal = scalarMap.to_rgba(nt)
                        cc=ax.plot(xc,yc,'-',color=colorVal,linewidth=1.5, label=str(tra_dates[nt]).split('_')[0])
            # # axis labels (not wanted)
            #if jn==1:
            #    ax[ii].set_xlabel(r'longitude (deg)', \
            #                      fontsize=18, labelpad=15)
            #    ax[ii].set_ylabel(r'latitude (deg)', \
            #                      fontsize=18, labelpad=20)
            # add a colorbar (not wanted)
            # add_axes[left, bottom, width, height]  
            #cbar_ax = fig.add_axes([0.15, 0.04, 0.7, 0.03])
            #cbar=plt.colorbar(cs0, cax=cbar_ax, \
            #                  format="%.2f", orientation="horizontal")
            #cbar.set_label('potential emission sensitivity (s)')
            
            
            # NO LEGEND DESIRED
            #plt.legend(loc=9,ncol=4, framealpha=0.8, fontsize=8, shadow=False)
            # delete the plot variable
            del pp
            # save figure
            fig.savefig(outfile, dpi=150)
            # close current figure:
            plt.close(fig)
            plt.clf()
    del ptrac_plot1, ptrac_plot2
    #
# #################################### #
# END FUNCTION SECTION
# #################################### #

# #########################################
# execute main part of the program:       #
# #########################################
if __name__=='__main__':
    main()                                #
    # #####################################
    # FINISH                              #
    # ################################### #
    quit("\n !!! THIS IS IT !!!\n" )      #
    # ################################### #
