import matplotlib.pyplot as plt
import numpy as np
import glob

plt.style.use('ds_style')

#####################################
# whattoplot = 'fcc'
# # basepath = '/home/dstrack/WBH/acloud/iasi/results/fcc/small/'
# basepath = '/net/kumbang/dstrack/validate/fcc/kernbereich/'
# files = sort(glob.glob(basepath+'fractional_cloud_cover_2017*.txt'))

whattoplot = 'ctp'
# basepath = '/home/dstrack/WBH/acloud/iasi/results/ctp/small/'
basepath = '/net/kumbang/dstrack/validate/ctp/kernbereich/'
files = sort(glob.glob(basepath+'cloud_top_pressure_2017*.txt'))

savepath = './'

saveFig = False

scalefactor = 1.8  # for scaling the figure size



############### ctp ####################################
if whattoplot == 'ctp':

    xticks = []  #  positions for xticks
    xlabs =[]  # xtick labels -> date of each day
    x = []  # list with data arrays for each day

    for xpos, file in enumerate(files):  # go through all files
        xticks.append(xpos+1)  # xtick position simply is number of file (+1 since python index starts with 0)
        xlabs.append(file[-6:-4]+'/'+file[-9:-7])  # append date of file

        ctp = np.loadtxt(file)  # load data
        ctp = ctp.reshape(ctp.size)  # reshape 2d array to 1d array
        ctp = ctp[~np.isnan(ctp)]  # get rid of all nan values
        ctp = ctp*0.01  # scale from Pa to hPa

        x.append(ctp)  # append data to list of data



    fig = plt.figure(1, figsize=(scalefactor*11.69,scalefactor*8.27))  # create figure in din A4 layout
    ax = fig.add_subplot(111)  # create axis
    bp = ax.boxplot(x,                      # boxplots for all columns in x
                    sym ='',                # do not display outliers
                    whis=[5,95],            # whiskers illustrate 5 and 95 percentile
                    patch_artist=True,      # artist needed to controll color, ... of box
                    widths=0.6)             # width of box

    # control box
    for box in bp['boxes']:
        box.set(linewidth=3, facecolor='green')

    # control median
    for median in bp['medians']:
        median.set(linewidth = 5, color = 'black')

    # control whisker
    for whisker in bp['whiskers']: # one upper and one lower
        whisker.set(linewidth = 3, color = 'black')

    # control caps
    for cap in bp['caps']:
        cap.set(linewidth = 3, color = 'black')


    # ax.set_ylabel('[%]')
    ax.set_ylabel('cloud top pressure [hPa]')

    # the next steps are to fit to other plots in the paper
    ax.set_xlim([0, 36.5])
    xlabs.append('27/06')
    xticks.append(36)
    ax.set_xticks(xticks[::7])                  # major ticks only on every int xtick position
    ax.set_xticks(xticks, minor = True)         # minor labels on every position
    ax.set_xticklabels(xlabs[::7], rotation=0)  # labels only on major ticks

    #ax.set_xlabel('date')
    #ax.set_title('fractional cloud cover')
    # ax.set_title('cloud top pressure')

    ax.plot([xlabs.index('29/05')+1.5, xlabs.index('29/05')+1.5],   # plot line to show periods
            [ax.set_ylim()[0],ax.set_ylim()[1]],                    # line should be beside last day of period
            color = 'black', linestyle ='--', linewidth=3)          # find index, add 1 because there is a offset between
    ax.plot([xlabs.index('12/06')+1.5, xlabs.index('12/06')+1.5],   # index and xposition, add 0.5 to be between to boxplots
            [ax.set_ylim()[0], ax.set_ylim()[1]],
            color = 'black', linestyle ='--', linewidth=3)

    ax.invert_yaxis()  # invert axis since heighest pressure is at lowest altitudes
    #fig.tight_layout()
    if saveFig:
        plt.savefig(savepath + 'plots/boxplot/ctp_boxplot_all_notitle.eps')  # save plot
        plt.close()
    else:
        plt.show()


elif whattoplot == 'fcc':

    xticks = []  # positions for xticks
    xlabs = []  # xtick labels -> date of each day
    x = []  # list with data arrays for each day

    for xpos, file in enumerate(files):  # go through all files
        xticks.append(xpos + 1)  # xtick position simply is number of file (+1 since python index starts with 0)
        xlabs.append(file[-6:-4]+'/'+file[-9:-7])  # append date of file

        ctp = np.loadtxt(file)  # load data
        ctp = ctp.reshape(ctp.size)  # reshape 2d array to 1d array
        ctp = ctp[~np.isnan(ctp)]  # get rid of all nan values

        x.append(ctp)  # append data to list of data

    fig = plt.figure(1, figsize=(scalefactor * 11.69, scalefactor * 8.27))  # create figure in din A4 layout
    ax = fig.add_subplot(111)  # create axis
    bp = ax.boxplot(x,  # boxplots for all columns in x
                    sym='',  # do not display outliers
                    whis=[5, 95],  # whiskers illustrate 5 and 95 percentile
                    patch_artist=True,  # artist needed to controll color, ... of box
                    widths=0.6)  # width of box

    # control box
    for box in bp['boxes']:
        box.set(linewidth=3, facecolor='green')

    # control median
    for median in bp['medians']:
        median.set(linewidth=5, color='black')

    # control whisker
    for whisker in bp['whiskers']:  # one upper and one lower
        whisker.set(linewidth=3, color='black')

    # control caps
    for cap in bp['caps']:
        cap.set(linewidth=3, color='black')

    ax.set_ylim([0,110])
    ax.set_ylabel('fractional cloud cover [%]')

    # the next steps are to fit to other plots in the paper
    ax.set_xlim([0, 36.5])
    xlabs.append('27/06')
    xticks.append(36)
    ax.set_xticks(xticks[::7])  # major ticks only on every int xtick position
    ax.set_xticks(xticks, minor=True)  # minor labels on every position
    ax.set_xticklabels(xlabs[::7], rotation=0)  # labels only on major ticks

    ax.plot([xlabs.index('29/05') + 1.5, xlabs.index('29/05') + 1.5],  # plot line to show periods
            [ax.set_ylim()[0], ax.set_ylim()[1]],  # line should be beside last day of period
            color='black', linestyle='--', linewidth=3)  # find index, add 1 because there is a offset between
    ax.plot([xlabs.index('12/06') + 1.5, xlabs.index('12/06') + 1.5],
            # index and xposition, add 0.5 to be between to boxplots
            [ax.set_ylim()[0], ax.set_ylim()[1]],
            color='black', linestyle='--', linewidth=3)

    # fig.tight_layout()
    if saveFig:
        plt.savefig(savepath + 'plots/boxplot/fcc_boxplot_all_notitle.eps')  # save plot
        plt.close()
    else:
        plt.show()

























