# Description:
#  Computing statistics of Marine Cold Air Outbreak (MCAO) index
#  (Kolstad, E. W., 2017, QJ, doi:10.1002/qj.3068)
#  for both MCAO and warm air advection (WAA) events
#
#  Knudsen, E., et al., 2018, Meteorological conditions
#  during the ACLOUD/PASCAL field campaign near Svalbard
#  in early summer 2017 - Fig. 6 and 14
#
#  Preparing data for plotting with NLC for
#  ACLOUD/PASCAL key periods
#
#  CDO based ksh script
#
# Use method:
#  Apply after ksh script calc_mcao.sh
#  ./prep_mcao_ts_stat4ncl.sh
#
# Author: 
#  Bernd Heinold, TROPOS
#  04318 Leipzig, Germany
#
# History:
#  October 2017
#
#!/bin/ksh
rm out1*.nc out2*.nc
cdo daymean mcao_ei_mjj1979-2017_small.nc out1.nc
cdo selyear,1979/2017 -daymean mcao_ei_mjj1979-2017_small.nc out2.nc

cdo selyear,2017 out1.nc out1_all.nc

cdo ydaymin out2.nc minfile
cdo ydaymax out2.nc maxfile
cdo ydaypctl,5 out2.nc minfile maxfile out1_05.nc
cdo ydaypctl,25 out2.nc minfile maxfile out1_25.nc
cdo ydaypctl,50 out2.nc minfile maxfile out1_50.nc
cdo ydaypctl,75 out2.nc minfile maxfile out1_75.nc
cdo ydaypctl,95 out2.nc minfile maxfile out1_95.nc

cdo setreftime,1979-01-01,0,1s -settaxis,2017-05-01,00:00:00,1day -setcalendar,standard out1_all.nc mcao_outn_all.nc 
cdo setreftime,1979-01-01,0,1s -settaxis,2017-05-01,00:00:00,1day -setcalendar,standard out1_05.nc mcao_outn_05.nc
cdo setreftime,1979-01-01,0,1s -settaxis,2017-05-01,00:00:00,1day -setcalendar,standard out1_25.nc mcao_outn_25.nc
cdo setreftime,1979-01-01,0,1s -settaxis,2017-05-01,00:00:00,1day -setcalendar,standard out1_50.nc mcao_outn_50.nc 
cdo setreftime,1979-01-01,0,1s -settaxis,2017-05-01,00:00:00,1day -setcalendar,standard out1_75.nc mcao_outn_75.nc
cdo setreftime,1979-01-01,0,1s -settaxis,2017-05-01,00:00:00,1day -setcalendar,standard out1_95.nc mcao_outn_95.nc
rm out1*.nc out2*.nc
#
# for histogram
cdo selday,23/31 -selmon,5 mcao_ei_mjj1979-2017_small.nc out1_may.nc
cdo selday,1/26 -selmon,6 mcao_ei_mjj1979-2017_small.nc out1_jun.nc
cdo mergetime out1_may.nc out1_jun.nc mcao_ei_acloud1979-2017_small.nc
cdo selyear,2017 mcao_ei_acloud1979-2017_small.nc mcao_ei_acloud2017_small.nc
cdo daymean mcao_ei_acloud1979-2017_small.nc mcao_ei_acloud1979-2017_daysmall.nc
cdo daymean mcao_ei_acloud2017_small.nc mcao_ei_acloud2017_daysmall.nc
rm out1*.nc

cdo daymean mcao_ei_mjj1979-2017_small.nc mcao_ei_mjj1979-2017_daysmall.nc
cdo daymean -selyear,2017 mcao_ei_mjj1979-2017_small.nc mcao_ei_mjj2017_daysmall.nc
rm out1*.nc

cdo daymax -selday,23/31 -selmon,5 -selname,mcao_nn,mcao_mx mcao_stat.nc out1_may.nc
cdo daymax -selday,1/26 -selmon,6 -selname,mcao_nn,mcao_mx mcao_stat.nc out1_jun.nc
cdo mergetime out1_may.nc out1_jun.nc mcao_stat_acloud.nc
rm out1*.nc

