; Description:
;  Ploting histogram with intensity and 
;  duration of Marine Cold Air Outbreaks (MCAO)
;
;  Knudsen, E., et al., 2018, Meteorological conditions
;  during the ACLOUD/PASCAL field campaign near Svalbard
;  in early summer 2017 - Fig. 14
;
; Use method:
;  Apply after ksh scripts
;  calc_mcao.sh, prep_mcao_ts_stat4ncl.sh
;  and ncl calc_ts_stat_mcao.ncl
;  ncl plot_ts_stat_mcoa.ncl
;
; Author:
;  Bernd Heinold, TROPOS
;  04318 Leipzig, Germany
;
; History:
;  October 2017
;
;------------------------------------------------------------------------------
; These files are loaded by default in NCL V6.2.0 and newer
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;
; This file still has to be loaded manually
load "$NCARG_ROOT/lib/ncarg/nclscripts/contrib/time_axis_labels.ncl"

begin
; Open the file
  inFileName1 = "mcao_stat_acloud.nc"
  inFile1 = addfile( inFileName1, "r" )

; lon = 480 ;
; lat = 94 ;
; time = UNLIMITED ; // (92 currently)
; double eof_ts2(time, lat, lon)
; double time(time); units = "hours since 1979-1-1 00:00:00"
;                    calendar = "proleptic_gregorian"

; Get the time units and set the first and last times that we want
  timeUnits = inFile1->time@units
  startDate = cd_inv_calendar( 1998, 05,  1, 00, 0, 0, timeUnits, 0 )
  endDate   = cd_inv_calendar( 2016, 07, 31, 00, 0, 0, timeUnits, 0 )

  inData    = inFile1->mcao_nn({startDate:endDate})

  data      = new((/3,dimsizes(inData)/),"double")
  data(0,:) = 0.  ; num_rcd
  data(1,:) = inFile1->mcao_nn({startDate:endDate})
  data(2,:) = inFile1->mcao_mx({startDate:endDate})

  timeUnits = "days since 1800-01-01 00:00:00"
  data&time = ut_convert( data&time, timeUnits )

; =================================================================
; plot bivariate (joint) pdf
; =================================================================
 x = data(1,:)
 y = data(2,:)
;x = where(x.eq.0,x@_FillValue,x)
;y = where(y.eq.0,y@_FillValue,y)
 printMinMax(x,False)
 printMinMax(y,False)

 opt          = True
 opt@binx_min = 2      ; minimum value for the x bin boundary.
 opt@binx_max = 10      ; maximum value for the x bin boundary.
 opt@biny_min = 2      ; minimum value for the y bin boundary.
 opt@biny_max = 6      ; maximum value for the y bin boundary. 
 opt@bin_nice = True
;opt@binx_nice = True
;opt@biny_nice = True

 pdf2 = pdfxy(x, y, 4, 4, opt) 
;printVarSummary(pdf2)
print(pdf2)
  pdf2 = where(pdf2.eq.0,pdf2@_FillValue,pdf2)

;plot   = new ( nSea, "graphic")
 wks    = gsn_open_wks("eps","mcaopdf_1998-2016x")

 res    = True
 res@gsnDraw              = False    ; do not draw picture
 res@gsnFrame             = False    ; do not advance frame
 res@cnFillOn             = True     ; turn on color fill
 res@cnFillPalette        = "precip2_15lev"  ;"amwg"   ; set color map
 res@gsnSpreadColors        = True             ; use full color map
 res@gsnSpreadColorStart    = 4               ; skipt black&white
 res@gsnSpreadColorEnd      = 15              ; skipt black&white
 res@cnFillMode           = "RasterFill"       ; Raster Mode
 res@cnLinesOn            = False    ; no contour lines
 res@cnLineLabelsOn       = False    ; no contour line labels
 res@cnInfoLabelOn        = False
;res@cnLabelBarEndStyle   = "ExcludeOuterBoxes"
;res@tiXAxisString        = awnc@varName
;res@tiYAxisString        = arel@varName
;res@tiXAxisOffsetYF      = 0.105

 res@gsnCenterString      = "  "
 plot = plt_pdfxy (wks, pdf2, res)
 maximize_output(wks,True)

end
