# Description:
#  Computing of Marine Cold Air Outbreak (MCAO) index 
#  following Kolstad, E. W. (2017), QJ, doi:10.1002/qj.3068
#  based on ECMWF re-analysis data
#
#  Knudsen, E., et al., 2018, Meteorological conditions
#  during the ACLOUD/PASCAL field campaign near Svalbard
#  in early summer 2017 - Fig. 6 and 14
#
#  CDO based ksh script
#
# Use method:
#  ./calc_mcao.sh
#
# Author: 
#  Bernd Heinold, TROPOS
#  04318 Leipzig, Germany
#
# History:
#  October 2017
#
#!/bin/ksh
inpdir="INPUT_DIRECTORY"
outdir="OUTPUT_DIRECTORY"
list=$(ls -d $inpdir/EI_T700_*)

for i in $list; do
    fnm=$((echo $i | cut -d/ -f7) | cut -d_ -f3)
    echo ${fnm}
    
    cdo -f nc gec,271.5 -selcode,235 EI_Tskin_Pmsl_${fnm} tmp_mask.nc
    cdo -f nc mulc,0.01 -selcode,151 EI_Tskin_Pmsl_${fnm} tmp_pmsl.nc

    cdo -f nc selcode,235 EI_Tskin_Pmsl_${fnm} tmp_skin.nc 
    cdo mul -pow,0.28571 -mulc,1000. -reci tmp_pmsl.nc tmp_skin.nc tmp_1000hpa.nc
    cdo -f nc mulc,1.0475 -selcode,130 -sellevidx,1 ${i} tmp_850hpa.nc 

    cdo fldmean -sellonlatbox,4.5,10.5,75.0,80.25 -mul -sub tmp_1000hpa.nc tmp_850hpa.nc tmp_mask.nc tmp_mcao_ei_${fnm}.nc
done
cdo mergetime tmp_mcao_ei_*.nc mcao_ei_mjj1979-2017_small.nc
rm tmp_*
