# Description:
#  Computing statistics of Arctic Dipole (AD) and
#  Arctic Oscillation (AO) indices
#
#  Knudsen, E., et al., 2018, Meteorological conditions
#  during the ACLOUD/PASCAL field campaign near Svalbard
#  in early summer 2017 - Fig. 12 and A2
#
#  Preparing data for plotting with NLC for
#  ACLOUD/PASCAL key periods
#
#  CDO based ksh script
#
# Usage:
#  Apply after ncl script calc_eof_day_RnW.ncl
#
# Author: 
#  Bernd Heinold, TROPOS
#  04318 Leipzig, Germany
#
# History:
#  October 2017
#
#!/bin/ksh
cdo yearmean -selday,23/29 -selmon,5 -mulc,-1. -selname,eof_ts1 eof_ts_I_79-17_15_20N_dstd.nc out1_cp.nc
cdo selday,30/31 -selmon,5 -mulc,-1. -selname,eof_ts1 eof_ts_I_79-17_15_20N_dstd.nc out1_wp1.nc
cdo selday,1/12 -selmon,6 -mulc,-1. -selname,eof_ts1 eof_ts_I_79-17_15_20N_dstd.nc out1_wp2.nc
cdo mergetime out1_wp1.nc out1_wp2.nc out1_wp3.nc
cdo yearmean out1_wp3.nc out1_wp.nc
cdo yearmean -selday,13/26 -selmon,6 -mulc,-1. -selname,eof_ts1 eof_ts_I_79-17_15_20N_dstd.nc out1_np.nc

 cdo setreftime,1979-01-01,0,1s -settaxis,1979-06-01,00:00:00,1year -setcalendar,standard out1_cp.nc outn_cp_ao_all.nc
 cdo setreftime,1979-01-01,0,1s -settaxis,1979-06-01,00:00:00,1year -setcalendar,standard out1_wp.nc outn_wp_ao_all.nc
 cdo setreftime,1979-01-01,0,1s -settaxis,1979-06-01,00:00:00,1year -setcalendar,standard out1_np.nc outn_np_ao_all.nc
rm out1*.nc
