#!/usr/bin/env python
# -*- coding: UTF-8 -*-

import numpy as np

# read the yearly NASA Neptune meltonset data (1979-2017), and adding the all the data to the alld variable
alld = []
for yr in range(1979,2018,1):
    alld.append(np.fromfile('/localdata/datasets/melt_onset/melt_update_2018/melt_update_2018/'\
                            +str(yr)+'730searlymelt.int.304.448.c',dtype='>h'))

# int16 datatype is transformed in float32 so it can accept NaN values
# transformed the list of arrays into a single 2D array
alld = np.reshape(alld,(39, 136192)).astype(np.float32)

# usable values are just at 75 or higher
alld[alld < 75] = np.nan

# mea is the mean value for 1979-2016 period
# ano is the 2017 anomaly relative to the 1979-2016 period
# arrays are reshaped for the NSIDC 25KM grid
mea = np.reshape(np.nanmean(alld[:-1],axis=0),(448,304))
ano = np.reshape(alld[-1],(448,304))-mea

np.save('/localdata/meltonset_local7916.npy',mea)
np.save('/localdata/early_ano.npy',ano)
