#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# creating figure for Anomalous  sea  ice  concentration  relative  to  climatologies  (2017  minus  1979–2016;  shading)  and  average  sea  ice  drift
import warnings
warnings.filterwarnings("ignore")

import numpy as np
from glob import glob
from matplotlib import pyplot as plt
from matplotlib import colors
from scipy.ndimage.morphology import binary_dilation
from netCDF4 import Dataset as NetCDFFile
from calendar import month_abbr
import re
import sys
from mpl_toolkits.basemap import Basemap, maskoceans
import pyresample as pr
from astropy.convolution import Gaussian2DKernel, convolve

import aggregate_nsidc_daily as nsidc

try:
    daterange = sys.argv[1]
except IndexError:
    print 'Range as first argument required: MM_DD-MM_DD, e.g. `06_10-06_20`'
    exit()

try:
    targetyear = sys.argv[2]
except IndexError:
    print 'Year as second argument required, e.g. `2017`'
    exit()

try:
    startyear = int(sys.argv[3])
except IndexError:
    startyear = 1979

try:
    endyear = int(sys.argv[4])
except IndexError:
    endyear = 2016
print 'Using data from {} until {} for mean'.format(startyear, endyear)

projection = "+proj=stere +lat_0=79 +lat_ts=70 +lon_0=8 +k=1 +x_0=0 +y_0=0 +a=6378273 +b=6356889.449 +units=m"
grid = 3.125
ar = [i*1000 for i in [-500, -500, 500, 500]]
xpoints = int((ar[2]-ar[0])/grid)/1000
ypoints = int((ar[3]-ar[1])/grid)/1000
area = pr.utils.get_area_def("nsidc_n","nsidc grid northern hemisphere", "nsidc_grid", projection, xpoints, ypoints, ar)
lon, lat = area.get_lonlats()

print 'Corner coordinates, lon, lat:'
print lon[-1,0], lat[-1,0]
print lon[0,0], lat[0,0]
print lon[0,-1], lat[0,-1]
print lon[-1,-1], lat[-1,-1]

lbls_mer = [0,0,0,1]
lbls_par = [1,0,1,0]
cbar_pad = 0.15

kernel_std = 1

def load_drift_data(flist):
    dxlist = []
    dylist = []
    for fname in flist:
        f = NetCDFFile(fname)
        lon = f.variables['lon'][:]
        lat = f.variables['lat'][:]
        dxlist.append(f.variables['dX'][0,:])
        dylist.append(f.variables['dY'][0,:])
    x, y = m(lon, lat)
    dxa = np.ma.masked_array(dxlist)
    dya = np.ma.masked_array(dylist)
    dx = dxa.sum(axis=0)/((len(flist)-dxa.mask.sum(axis=0))*2)
    dy = dya.sum(axis=0)/((len(flist)-dya.mask.sum(axis=0))*2)
    uvc = dx + 1j * dy
    uvmag = np.abs(uvc)
    uvtheta = np.angle(uvc)
    ntheta = uvtheta - np.radians(53)
    uvcout = uvmag * np.exp(1j * ntheta)
    dx = uvcout.real
    dy = uvcout.imag
    return x, y, dx, dy

def create_basemap():
    m = Basemap(lon[-1,0], lat[-1,0], lon[0,-1], lat[0,-1], projection='stere', lat_0=79, lon_0=8,lat_ts=70, resolution='h')

    m.drawcoastlines(linewidth=0.2)
    m.fillcontinents()
    m.drawmeridians(np.arange(-180.,181.,5.), labels=lbls_mer, linewidth=0.3, latmax=90)
    m.drawparallels(np.arange(-80.,91.,2.), labels=lbls_par, linewidth=0.3, latmax=90)

    return m

files = glob('data/mean_*__{}.npy'.format(daterange))
if not files:
    print 'Range unknown'
    exit()
data = []
for f in files:
    if int(f[10:14]) >= startyear and int(f[10:14]) <= endyear:
        data.append(np.load(f))
meanimg = np.array(data).mean(axis=0)

targetimg = np.load('data/mean_{}__{}.npy'.format(targetyear, daterange))

img = targetimg - meanimg

nsidc_swath = pr.geometry.SwathDefinition(lats=nsidc.lat, lons=nsidc.lon)
nsidc_img = pr.kd_tree.resample_nearest(nsidc_swath, img, area, radius_of_influence=50000, fill_value=None)
nsidc_img = convolve(nsidc_img, Gaussian2DKernel(5), boundary='extend')
nsidc_img[~maskoceans(lon, lat, nsidc_img, resolution='h').mask] = np.nan

ice_edge = pr.kd_tree.resample_nearest(nsidc_swath, targetimg, area, radius_of_influence=50000, fill_value=None)
ice_edge = convolve(ice_edge, Gaussian2DKernel(5), boundary='extend')
ice_edge[~maskoceans(lon, lat, ice_edge, resolution='h').mask] = np.nan

m = create_basemap()
vlim = max(-np.nanmin(nsidc_img), np.nanmax(nsidc_img))
print vlim
vlim = 55
bounds = np.linspace(-vlim, vlim, 12)
vlim = 60
bounds = np.array([-60., -50., -40., -30., -20., -10., -5., 5.,  10.,  20.,  30.,  40., 50.,  60.])
norm = colors.BoundaryNorm(boundaries=bounds, ncolors=256)
m.imshow(nsidc_img, origin='upper', norm=norm, cmap='bwr', vmin=-vlim, vmax=vlim)
m.contour(lon, lat, ice_edge, levels=(15,), colors='k', origin='upper', vmin=0, vmax=100, latlon=True)

drift_flist = None
if daterange == '05_23-05_29':
    drift_flist = [
            'data/ice_drift_nh_polstere-625_multi-oi_201705231200-201705251200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201705241200-201705261200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201705251200-201705271200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201705261200-201705281200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201705271200-201705291200.nc',
            ]
elif daterange == '05_30-06_12':
    drift_flist = [
            'data/ice_drift_nh_polstere-625_multi-oi_201705301200-201706011200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201705311200-201706021200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706011200-201706031200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706021200-201706041200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706031200-201706051200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706041200-201706061200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706051200-201706071200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706061200-201706081200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706071200-201706091200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706081200-201706101200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706091200-201706111200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706101200-201706121200.nc',
            ]
elif daterange == '06_13-06_26':
    drift_flist = [
            'data/ice_drift_nh_polstere-625_multi-oi_201706131200-201706151200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706141200-201706161200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706151200-201706171200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706161200-201706181200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706171200-201706191200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706181200-201706201200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706191200-201706211200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706201200-201706221200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706211200-201706231200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706221200-201706241200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706231200-201706251200.nc',
            'data/ice_drift_nh_polstere-625_multi-oi_201706241200-201706261200.nc',
            ]

if drift_flist is not None:
    x, y, dx, dy = load_drift_data(drift_flist)
    q = m.quiver(x, y, dx, dy, scale=100, angles='xy', pivot='mid', width=0.005, headwidth=5)
    plt.quiverkey(q, 0.8, 0.05, 10, '10 km/d', labelpos='E')

plt.savefig('anomalies_{}__{}_since_{}_until_{}.eps'.format(targetyear, daterange, startyear, endyear), bbox_inches='tight')
plt.savefig('anomalies_{}__{}_since_{}_until_{}.png'.format(targetyear, daterange, startyear, endyear), bbox_inches='tight')
plt.close()

plt.figure(figsize=(7, 0.3))
plt.imshow(nsidc_img, norm=norm, cmap='bwr', vmin=-vlim, vmax=vlim)
plt.gca().set_visible(False)
cax = plt.axes([0.1, 0.2, 0.8, 0.6])
cbar = plt.colorbar(orientation="horizontal", cax=cax, label='Sea ice concentration [%]')
cbar.set_ticks(bounds)
plt.savefig("colorbar.eps", bbox_inches='tight')
plt.savefig("colorbar.png", bbox_inches='tight')
