#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# Creating figures with average early meltonset and melt onset anomaly with sea ice edge contour
import warnings
warnings.filterwarnings("ignore")

import numpy as np
from glob import glob
from matplotlib import pyplot as plt
from matplotlib import colors
import matplotlib as mpl
from scipy.ndimage.morphology import binary_dilation
from netCDF4 import Dataset as NetCDFFile
from calendar import month_abbr
import re
import sys
from mpl_toolkits.basemap import Basemap, maskoceans
import pyresample as pr
from astropy.convolution import Gaussian2DKernel, convolve

import aggregate_nsidc_daily as nsidc


projection = "+proj=stere +lat_0=79 +lat_ts=70 +lon_0=8 +k=1 +x_0=0 +y_0=0 +a=6378273 +b=6356889.449 +units=m"
grid = 3.125
ar = [i*1000 for i in [-500, -500, 500, 500]]
xpoints = int((ar[2]-ar[0])/grid)/1000
ypoints = int((ar[3]-ar[1])/grid)/1000
area = pr.utils.get_area_def("nsidc_n","nsidc grid northern hemisphere", "nsidc_grid", projection, xpoints, ypoints, ar)
lon, lat = area.get_lonlats()

print 'Corner coordinates, lon, lat:'
print lon[-1,0], lat[-1,0]
print lon[0,0], lat[0,0]
print lon[0,-1], lat[0,-1]
print lon[-1,-1], lat[-1,-1]

lbls_mer = [0,0,0,1]
lbls_par = [1,0,1,0]
cbar_pad = 0.15

kernel_std = 1

def load_drift_data(flist):
    dxlist = []
    dylist = []
    for fname in flist:
        f = NetCDFFile(fname)
        lon = f.variables['lon'][:]
        lat = f.variables['lat'][:]
        dxlist.append(f.variables['dX'][0,:])
        dylist.append(f.variables['dY'][0,:])
    x, y = m(lon, lat)
    dxa = np.ma.masked_array(dxlist)
    dya = np.ma.masked_array(dylist)
    dx = dxa.sum(axis=0)/((len(flist)-dxa.mask.sum(axis=0))*2)
    dy = dya.sum(axis=0)/((len(flist)-dya.mask.sum(axis=0))*2)
    uvc = dx + 1j * dy
    uvmag = np.abs(uvc)
    uvtheta = np.angle(uvc)
    ntheta = uvtheta - np.radians(53)
    uvcout = uvmag * np.exp(1j * ntheta)
    dx = uvcout.real
    dy = uvcout.imag
    return x, y, dx, dy

def create_basemap():
    m = Basemap(lon[-1,0], lat[-1,0], lon[0,-1], lat[0,-1], projection='stere', lat_0=79, lon_0=8,lat_ts=70, resolution='h')

    m.drawcoastlines(linewidth=0.2)
    m.fillcontinents()
    m.drawmeridians(np.arange(-180.,181.,5.), labels=lbls_mer, linewidth=0.3, latmax=90)
    m.drawparallels(np.arange(-80.,91.,2.), labels=lbls_par, linewidth=0.3, latmax=90)

    return m

# reading SIC data for needed period period
targetimg = np.load('data/mean_2017__05_23-06_26.npy')


nsidc_swath = pr.geometry.SwathDefinition(lats=nsidc.lat, lons=nsidc.lon)

ice_edge = pr.kd_tree.resample_nearest(nsidc_swath, targetimg, area, radius_of_influence=50000, fill_value=None)
ice_edge = convolve(ice_edge, Gaussian2DKernel(5), boundary='extend')
ice_edge[~maskoceans(lon, lat, ice_edge, resolution='h').mask] = np.nan

aaa = mpl.cm.get_cmap('bwr')
aux_c = aaa(np.linspace(0,1,8))
cbwr = mpl.colors.ListedColormap(aux_c)

m = create_basemap()
anom = np.ma.masked_invalid(np.load('data/early_ano.npy'))
m.pcolormesh(nsidc.lon, nsidc.lat, anom[1:,:], latlon=True, cmap=cbwr, vmin=-40, vmax=40)
cbar = m.colorbar(pad=cbar_pad, label='Days')

m.contour(lon, lat, ice_edge, levels=(15,), colors='k', origin='upper', vmin=0, vmax=100, latlon=True)

plt.savefig('earlymeltano_arctic_vx.eps', bbox_inches='tight')
plt.savefig('earlymeltano_arctic_vx.png', bbox_inches='tight')
plt.close()


# m = create_basemap()
# anom = np.ma.masked_invalid(np.load('data/contm_ano.npy'))
# m.pcolormesh(nsidc.lon, nsidc.lat, anom[1:,:], latlon=True, cmap=cbwr, vmin=-40, vmax=40)
# cbar = m.colorbar(pad=cbar_pad, label='Days')
# 
# m.contour(lon, lat, ice_edge, levels=(15,), colors='k', origin='upper', vmin=0, vmax=100, latlon=True)
# 
# plt.savefig('meltano_arctic_vx.eps', bbox_inches='tight')
# plt.savefig('meltano_arctic_vx.png', bbox_inches='tight')
# plt.close()


m = create_basemap()
onset = np.ma.masked_invalid(np.load('data/meltonset_local7916.npy'))

# creating custom colormap
c1 = plt.cm.tab20b.colors
c2 = plt.cm.tab20c.colors
cya = mpl.colors.hex2color('#127A7A')
cya2 = mpl.colors.hex2color('#47A8A8')
cya3 = mpl.colors.hex2color('#7AC3C3')
cya4 = mpl.colors.hex2color('#A9DDDD')
cyam = tuple([cya,cya2,cya3,cya4])

new_cmap = (c1[4*4:(4*4+4)],c1[3*4:(3*4+4)],c2[1*4:(1*4+4)],c1[2*4:(2*4+4)],c1[1*4:(1*4+4)],\
                     c2[2*4:(2*4+4)],cyam,c2[0*4:(0*4+4)],c2[3*4:(3*4+4)],c2[4*4:(4*4+4)])

hh = mpl.colors.ListedColormap(tuple([y for x in new_cmap for y in x]))

m.pcolormesh(nsidc.lon, nsidc.lat, onset[1:,:], latlon=True, cmap=hh, vmin=80, vmax=160)
cbar = m.colorbar(pad=cbar_pad, label='Day of the Year')


plt.savefig('7916_earlymelt_Arctic_e434_vx.eps', bbox_inches='tight')
plt.savefig('7916_earlymelt_Arctic_e434_vx.png', bbox_inches='tight')
plt.close()
