#!/usr/bin/env python
# -*- coding: UTF-8 -*-

import locale
locale.setlocale(locale.LC_ALL, 'C')

import numpy as np
from glob import glob
from matplotlib import pyplot as plt
import sys
from datetime import date

import argparse

def parse_arg_date(string):
    try:
        return date(*map(int, string.split('-')))
    except:
        raise argparse.ArgumentTypeError('Invalid date format or date.')

def add_day(indate):
    return date.fromordinal(indate.toordinal() + 1)

def iter_dates(start, end):
    i = 0
    while start <= end:
        yield (i, start)
        start = add_day(start)
        i += 1

parser = argparse.ArgumentParser(description='Specify date range for mean.')
parser.add_argument('start',
                    help='Start date in YYYY-MM-DD',
                    type=parse_arg_date)
parser.add_argument('end',
                    help='End date in YYYY-MM-DD',
                    type=parse_arg_date)



# Iterations of the binary dilatation to increase the land mask by one pixel.
dilatations = 0

# north
H = ""
Hname = "Northern"
sha = [448, 304]
# files_wc = '/mnt/SMOS_data_HD6/miklip/north/sidads.colorado.edu/daily/'
files_wc = '/localdata/mgerken/miklip/north/daily/'
lat = '../nsidc_monthly_data/psn25lats_v3.dat'
lon = '../nsidc_monthly_data/psn25lons_v3.dat'
circle = np.load('../nsidc_monthly_data/circle_north.npy')

lon = np.fromfile(lon, dtype=np.int32) / 10e4
lon.shape = sha
lon = lon.astype(np.float)
lat = np.fromfile(lat, dtype=np.int32) / 10e4
lat.shape = sha

if __name__ == "__main__":
    args = parser.parse_args()
    for year in range(1979, 2018):  # bis 2017
        print "processing %i:" % year,
        diryear = str(year)
        data = []
        if year > 2016:
            diryear = str(year) + 'nrt'
        for i, dat in iter_dates(args.start.replace(year=year), args.end.replace(year=year)):
            files = glob(files_wc+"%s/nt_%i%02i%02i_*.bin" % (diryear, dat.year, dat.month, dat.day))
            if len(files) == 0:
                continue
            f = files[0]
            print dat.strftime('%d.%m.'),
            # ignore the first 300 bytes rubbish
            d = np.fromfile(f, dtype=np.uint8)[300:]
            d.shape = sha  # NSIDC 25 km grid
            idx = d > 250
            d = (d / 2.50)
            d[idx | circle] = np.nan
            data.append(d)
        data = np.array(data)
        mean = data.mean(axis=0)
        np.save('data/mean_{}__{:02d}_{:02d}-{:02d}_{:02d}.npy'.format(year, args.start.month, args.start.day, args.end.month, args.end.day), mean)
        print
